@@ -15,9 +15,10 @@ from pycatia.knowledge_interfaces.length import Length
 
 
 class HybridShapeCircleBitangentRadius(HybridShapeCircle):
-
     """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
 
                 | System.IUnknown
@@ -56,6 +57,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def begin_of_circle(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property BeginOfCircle() As long
                 | 
@@ -88,6 +91,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def curve1(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Curve1() As Reference
                 | 
@@ -121,6 +126,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def curve2(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Curve2() As Reference
                 | 
@@ -153,6 +160,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def diameter(self) -> Length:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Diameter() As Length (Read Only)
                 | 
@@ -176,6 +185,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def diameter_mode(self) -> bool:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property DiameterMode() As boolean
                 | 
@@ -210,6 +221,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def discrimination_index(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property DiscriminationIndex() As long
                 | 
@@ -245,6 +258,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def orientation1(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation1() As long
                 | 
@@ -280,6 +295,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def orientation2(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Orientation2() As long
                 | 
@@ -315,6 +332,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def radius(self) -> Length:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Radius() As Length (Read Only)
                 | 
@@ -338,6 +357,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def support(self) -> Reference:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property Support() As Reference
                 | 
@@ -360,7 +381,7 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     @support.setter
     def support(self, reference_support: Reference):
         """
-        :param Reference value:
+        :param Reference reference_support:
         """
 
         self.hybrid_shape_circle_bitangent_radius.Support = reference_support.com_object
@@ -369,6 +390,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def tangent_orientation1(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property TangentOrientation1() As long
                 | 
@@ -403,6 +426,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def tangent_orientation2(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property TangentOrientation2() As long
                 | 
@@ -437,6 +462,8 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
     def trim_mode(self) -> int:
         """
         .. note::
+            :class: toggle
+
             CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                 | o Property TrimMode() As long
                 | 
@@ -472,4 +499,4 @@ class HybridShapeCircleBitangentRadius(HybridShapeCircle):
         self.hybrid_shape_circle_bitangent_radius.TrimMode = value
 
     def __repr__(self):
-        return f'HybridShapeCircleBitangentRadius(name="{ self.name }")'
+        return f'HybridShapeCircleBitangentRadius(name="{self.name}")'
