@@ -108,7 +108,7 @@ class Line(HybridShape):
 
         self.line.SecondUptoElem = reference_element
 
-    def get_direction(self, o_direction: tuple) -> None:
+    def get_direction(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -138,26 +138,20 @@ class Line(HybridShape):
                 |     See also:
                 |         HybridShapeFactory
 
-        :param tuple o_direction:
         :return: None
         :rtype: None
         """
-        return self.line.GetDirection(o_direction)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_direction'
-        # # vba_code = """
-        # # Public Function get_direction(line)
-        # #     Dim oDirection (2)
-        # #     line.GetDirection oDirection
-        # #     get_direction = oDirection
-        # # End Function
-        # # """
+        vba_function_name = "get_direction"
+        vba_code = """
+        Public Function get_direction(line)
+            Dim oDirection (2)
+            line.GetDirection oDirection
+            get_direction = oDirection
+        End Function
+        """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def get_origin(self, o_origin: tuple) -> None:
         """
