@@ -8,6 +8,7 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.in_interfaces.file import File
 from pycatia.system_interfaces.collection import Collection
@@ -81,5 +82,9 @@ class Files(Collection):
 
         return File(self.files.item(n + 1))
 
+    def __iter__(self) -> Iterator[File]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Files(name="{self.name}")'
