@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.in_interfaces.printer import Printer
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Printers(Collection):
@@ -81,5 +82,9 @@ class Printers(Collection):
 
         return Printer(self.printers.item(n + 1))
 
+    def __iter__(self) -> Iterator[Printer]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Printers(name="{self.name}")'
