@@ -9,9 +9,15 @@
         
 """
 
+from typing import TYPE_CHECKING
+
 from pycatia.in_interfaces.camera import Camera
 from pycatia.system_interfaces.any_object import AnyObject
 
+if TYPE_CHECKING:
+    from pycatia.in_interfaces.viewer_2d import Viewer2D
+    from pycatia.in_interfaces.viewer_3d import Viewer3D
+
 
 class Viewer(AnyObject):
     """
@@ -172,7 +178,7 @@ class Viewer(AnyObject):
         """
         return self.viewer.CaptureToFile(i_format, i_file)
 
-    def get_background_color(self, color: tuple) -> None:
+    def get_background_color(self) -> None:
         """
         .. note::
             :class: toggle
@@ -195,22 +201,27 @@ class Viewer(AnyObject):
         :return: None
         :rtype: None
         """
-        return self.viewer.GetBackgroundColor(color)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_background_color'
-        # # vba_code = """
-        # # Public Function get_background_color(viewer)
-        # #     Dim color (2)
-        # #     viewer.GetBackgroundColor color
-        # #     get_background_color = color
-        # # End Function
-        # # """
+        vba_function_name = 'get_background_color'
+        vba_code = """
+        Public Function get_background_color(viewer)
+            Dim color (2)
+            viewer.GetBackgroundColor color
+            get_background_color = color
+        End Function
+        """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+
+    def create_viewer_2d(self) -> 'Viewer2D':
+        from pycatia.in_interfaces.viewer_2d import Viewer2D
+
+        return Viewer2D(self.viewer)
+
+    def create_viewer_3d(self) -> 'Viewer3D':
+        from pycatia.in_interfaces.viewer_3d import Viewer3D
+
+        return Viewer3D(self.viewer)
 
     def new_camera(self) -> Camera:
         """
