@@ -182,7 +182,7 @@ class Viewpoint3D(AnyObject):
 
         self.viewpoint_3d.Zoom = value
 
-    def get_origin(self, origin: tuple) -> None:
+    def get_origin(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -200,28 +200,22 @@ class Viewpoint3D(AnyObject):
                 |          Dim origin(2)
                 |          NiceViewpoint.GetOrigin origin
 
-        :param tuple origin:
-        :return: None
-        :rtype: None
+        :return: tuple
+        :rtype: tuple
+        """
+        vba_function_name = 'get_origin'
+        vba_code = """
+        Public Function get_origin(viewpoint_3d)
+            Dim origin (2)
+            viewpoint_3d.GetOrigin origin
+            get_origin = origin
+        End Function
         """
-        return self.viewpoint_3d.GetOrigin(origin)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_origin'
-        # # vba_code = """
-        # # Public Function get_origin(viewpoint_3d)
-        # #     Dim origin (2)
-        # #     viewpoint_3d.GetOrigin origin
-        # #     get_origin = origin
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_sight_direction(self, o_sight: tuple) -> None:
+    def get_sight_direction(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -240,28 +234,22 @@ class Viewpoint3D(AnyObject):
                 |          Dim sight(2)
                 |          NiceViewpoint.GetSightDirection sight
 
-        :param tuple o_sight:
-        :return: None
-        :rtype: None
+        :return: tuple
+        :rtype: tuple
+        """
+        vba_function_name = 'get_sight_direction'
+        vba_code = """
+        Public Function get_sight_direction(viewpoint_3d)
+            Dim oSight (2)
+            viewpoint_3d.GetSightDirection oSight
+            get_sight_direction = oSight
+        End Function
         """
-        return self.viewpoint_3d.GetSightDirection(o_sight)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_sight_direction'
-        # # vba_code = """
-        # # Public Function get_sight_direction(viewpoint_3d)
-        # #     Dim oSight (2)
-        # #     viewpoint_3d.GetSightDirection oSight
-        # #     get_sight_direction = oSight
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
-    def get_up_direction(self, o_up: tuple) -> None:
+    def get_up_direction(self) -> tuple:
         """
         .. note::
             :class: toggle
@@ -278,26 +266,21 @@ class Viewpoint3D(AnyObject):
                 |          Dim up(2)
                 |          NiceViewpoint.GetUpDirection up
 
-        :param tuple o_up:
-        :return: None
-        :rtype: None
+        :return: tuple
+        :rtype: tuple
         """
-        return self.viewpoint_3d.GetUpDirection(o_up)
-        # # # # Autogenerated comment: 
-        # # some methods require a system service call as the methods expects a vb array object
-        # # passed to it and there is no way to do this directly with python. In those cases the following code
-        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
-        # # vba_function_name = 'get_up_direction'
-        # # vba_code = """
-        # # Public Function get_up_direction(viewpoint_3d)
-        # #     Dim oUp (2)
-        # #     viewpoint_3d.GetUpDirection oUp
-        # #     get_up_direction = oUp
-        # # End Function
-        # # """
 
-        # # system_service = self.application.system_service
-        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
+        vba_function_name = 'get_up_direction'
+        vba_code = """
+        Public Function get_up_direction(viewpoint_3d)
+            Dim oUp (2)
+            viewpoint_3d.GetUpDirection oUp
+            get_up_direction = oUp
+        End Function
+        """
+
+        system_service = self.application.system_service
+        return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])
 
     def put_origin(self, origin: tuple) -> None:
         """
