@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.in_interfaces.window import Window
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Windows(Collection):
@@ -109,5 +110,9 @@ class Windows(Collection):
 
         return Window(self.windows.item(n + 1))
 
+    def __iter__(self) -> Iterator[Window]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Windows(name="{self.name}")'
