@@ -8,12 +8,13 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from typing import TYPE_CHECKING
 
 from pycatia.knowledge_interfaces.free_parameter import FreeParameter
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 if TYPE_CHECKING:
     from pycatia.knowledge_interfaces.real_param import RealParam
@@ -116,5 +117,9 @@ class FreeParameters(Collection):
 
         return FreeParameter(self.free_parameters.item(n + 1))
 
+    def __iter__(self) -> Iterator[FreeParameter]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'FreeParameters(name="{self.name}")'
