@@ -8,10 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class List(Collection):
@@ -170,5 +171,9 @@ class List(Collection):
 
         return AnyObject(self.list.item(n + 1))
 
+    def __iter__(self) -> Iterator[AnyObject]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'List(name="{self.name}")'
