@@ -8,9 +8,11 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.knowledge_interfaces.parameter_set import ParameterSet
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class ParameterSets(Collection):
@@ -111,5 +113,9 @@ class ParameterSets(Collection):
 
         return ParameterSet(self.parameter_sets.item(n + 1))
 
+    def __iter__(self) -> Iterator[ParameterSet]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'ParameterSets(name="{self.name}")'
