@@ -8,7 +8,7 @@
         and thus help debugging in pycatia.
         
 """
-
+from typing import Iterator
 from typing import TYPE_CHECKING
 from typing import Optional
 
@@ -25,8 +25,8 @@ from pycatia.knowledge_interfaces.str_param import StrParam
 from pycatia.knowledge_interfaces.units import Units
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
-from pycatia.types import any_parameter
+from pycatia.types.general import cat_variant
+from pycatia.types.general import any_parameter
 
 if TYPE_CHECKING:
     from pycatia.knowledge_interfaces.parameter_set import ParameterSet
@@ -528,5 +528,9 @@ class Parameters(Collection):
 
         return Parameter(self.parameters.item(n + 1))
 
+    def __iter__(self) -> Iterator[Parameter]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Parameters(name="{self.name}")'
