@@ -621,18 +621,20 @@ class AxisSystem(AnyObject):
                 |          Dim vectorYCoord(2)
                 |          axisSystem.GetVectors vectorXCoord, vectorYCoord
 
-        :param tuple o_vector_x:
-        :param tuple o_vector_y:
         :return: None
         :rtype: None
         """
 
-        vba_function_name = 'get_vectors'
+        vba_function_name = "get_vectors"
         vba_code = """
         Public Function get_vectors(axis_system)
             Dim oVectorX (2)
-            axis_system.GetVectors oVectorX
-            get_vectors = oVectorX
+            Dim oVectorY (2)
+            axis_system.GetVectors oVectorX, oVectorY
+            Dim oVectors (1)
+            oVectors(0) = oVectorX
+            oVectors(1) = oVectorY
+            get_vectors = oVectors
         End Function
         """
 
