@@ -8,13 +8,14 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
 
 from pywintypes import com_error
 
 from pycatia.exception_handling.exceptions import CATIAApplicationException
 from pycatia.mec_mod_interfaces.hybrid_body import HybridBody
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class HybridBodies(Collection):
@@ -113,5 +114,9 @@ class HybridBodies(Collection):
 
         return HybridBody(self.hybrid_bodies.item(n + 1))
 
+    def __iter__(self) -> Iterator[HybridBody]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'HybridBodies(name="{self.name}")'
