@@ -8,10 +8,12 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.in_interfaces.viewpoint_3d import Viewpoint3D
 from pycatia.navigator_interfaces.annotated_view import AnnotatedView
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class AnnotatedViews(Collection):
@@ -186,5 +188,9 @@ class AnnotatedViews(Collection):
 
         return AnnotatedView(self.annotated_views.item(n + 1))
 
+    def __iter__(self) -> Iterator[AnnotatedView]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'AnnotatedViews(name="{self.name}")'
