@@ -8,10 +8,12 @@
         and thus help debugging in pycatia.
         
 """
+from typing import Iterator
+
 from pycatia.navigator_interfaces.hyperlink import Hyperlink
 from pycatia.system_interfaces.any_object import AnyObject
 from pycatia.system_interfaces.collection import Collection
-from pycatia.types import cat_variant
+from pycatia.types.general import cat_variant
 
 
 class Hyperlinks(Collection):
@@ -183,5 +185,9 @@ class Hyperlinks(Collection):
 
         return Hyperlink(self.hyperlinks.item(n + 1))
 
+    def __iter__(self) -> Iterator[Hyperlink]:
+        for i in range(self.count):
+            yield self.child_object(self.com_object.item(i + 1))
+
     def __repr__(self):
         return f'Hyperlinks(name="{self.name}")'
